##  6. What do “Approval” or “Status” mean, once I ordered new software on the Portal?
The Approval state marks whether you need approval to request the software or not.
The Status shows whether the software is available for requesting or not.
"approval" : "Approved" - "status" : "Available"
"approval" : "With Limitations" - "status" : "Available"
"approval" : " " - "status" : "Approval requested"
"approval" : " " - "status" : "Approval denied"
